from django.contrib import admin
from glinks.models import Blueprint, Glink

class GlinkAdmin(admin.ModelAdmin):
	def get_readonly_fields(self, request, obj=None):
		return ['impressions', 'clicks']

# Register your models here.
admin.site.register(Blueprint)
admin.site.register(Glink, GlinkAdmin)


from django import template
from django.conf import settings
from django.utils.encoding import smart_str
from django.template import TextNode, Node

from utilities import *


register = template.Library()

def parseGlinkNode(command):
	options = {}

	for op in command:
		if "=" in op:
			tmp_list = op.split("=")
			if tmp_list[0] in possibleGlinkOptions():
				options[tmp_list[0]] = tmp_list[1].replace('"', '').replace("'", '').strip()
			else:
				print glinkErrorLead() + "Incorrect command given in template.\n"
		if "as" in op:
			options["as"] = command[command.index("as")+1]
	return options

class GlinkNodeCustom(Node):
	child_nodelists = ('nodelist_file', 'nodelist_empty')

	def __init__(self, parser, token):
		command = token.split_contents()
		self.must_be_first = None
		self.as_var = None
		self.blueprint = None
		self.glink = None
		self.options = {}
		self.nodelist_file = None

		self.options = parseGlinkNode(command)

		for key, value in self.options.items():
			if key == "blueprint":
				self.blueprint = value

		# Close block.
		if command[-2] == 'as':
			self.as_var = command[-1]
			self.nodelist_file = parser.parse(('empty', 'endcustom_glink',))
			if parser.next_token().contents == 'empty':
				self.nodelist_empty = parser.parse(('endcustom_glink',))
				parser.delete_first_token()
		
		# Nifty little switcharoo from string to object.
		self.blueprint = Blueprint.objects.get(name=self.blueprint)

		try:
			glinks = Glink.objects.filter(blueprint=self.blueprint)
			self.glink = glinks.order_by('?')[0]

			# Increment impression count.
			self.glink.impressions = self.glink.impressions + 1
			self.glink.save()
		except Exception as e:
			print str(e)

	def render(self, context):
		output = None

		if self.as_var:
			context.push()
			context[self.as_var] = self.glink
			output = self.nodelist_file.render(context)
			context.pop()
		else:
			output = self.glink.image.url

		return output

class GlinkNode(Node):
	child_nodelists = ('nodelist_file', 'nodelist_empty')

	def __init__(self, parser, token):
		command = token.split_contents()
		self.must_be_first = None
		self.as_var = None
		self.blueprint = None
		self.glink = None
		self.options = {}
		self.nodelist_file = None

		self.options = parseGlinkNode(command)

		for key, value in self.options.items():
			if key == "blueprint":
				self.blueprint = value
		# Nifty little switcharoo from string to object.
		self.blueprint = Blueprint.objects.get(name=self.blueprint)

		try:
			glinks = Glink.objects.filter(blueprint=self.blueprint)
			self.glink = glinks.order_by('?')[0]

			# Increment impression count.
			self.glink.impressions = self.glink.impressions + 1
			self.glink.save()
		except Exception as e:
			print str(e)

	def render(self, context):
		#height="42" width="42"
		glink_page = "'glink/" + str(self.glink.pk) + "'"
		img_lead = "<img src="
		img_url = "'" + str(self.glink.image.url) + "'"
		on_click = " onclick=location.href="
		glink_page = "'/glink/" + str(self.glink.pk) + "'"
		height = " height='" + str(self.blueprint.height) + "'"
		width = " width='" + str(self.blueprint.width) + "'"
		img_close = ">"
		return img_lead + img_url + on_click + glink_page + height + width + img_close


@register.assignment_tag
def getRandomGlink():
	return Glink.objects.all().order_by('?')[0]
		
@register.tag
def custom_glink(parser, token):
	node = GlinkNodeCustom(parser, token)
	return node

@register.tag
def glink(parser, token):
	node = GlinkNode(parser, token)
	return node





from django.http import HttpResponseRedirect
from glinks.models import Glink, Blueprint

# Create your views here.
def glink_counter(request, glink_id):
	glink = Glink.objects.get(pk=glink_id)
	glink.clicks = glink.clicks + 1
	glink.save()
	return HttpResponseRedirect(glink.URL)


from django.db import models
from django.conf import settings


# Create your models here.
class Blueprint(models.Model):

	# Name of blueprint
	name   = models.CharField(max_length=50, null=True, blank=False)

	# Height/width in pixels
	height = models.IntegerField(null=True, blank=True)
	width  = models.IntegerField(null=True, blank=True)

	def __unicode__(self):
		return self.name

class Glink(models.Model):

	blueprint = models.ForeignKey(Blueprint, null=True)

	# Glink image
	image  = models.ImageField(null=False, blank=False, upload_to="glink_images")

	# Glink target URL
	URL    = models.URLField(null=True, blank=True)

	# Click/impression tracking
	clicks = models.BigIntegerField(null=False, blank=True, default=0)
	impressions = models.BigIntegerField(null=False, blank=True, default=0)


from distutils.core import setup

setup(
    name='django-glinks',
    version='0.1.2',
    author='Shawn Simon',
    author_email='shawn.simon.developer@gmail.com',
    packages=['glinks'],
    url='http://pypi.python.org/pypi/django-glinks/',
    license='LICENSE.txt',
    description='Interal add manager for django sites.',
    long_description=open('README.txt').read(),
    install_requires=[
        "Django >= 1.6.0",
    ],
)